# Style

A collection of coding / organizational styles we follow in [diagram-js](https://github.com/bpmn-io/diagram-js).


## Building Components


### The API of a Component

* Programmatic API
* Events it consumes
* Events it produces
* Structure it exposes (SVG elements, ...)


### Sample Component

```javascript
var defaultModule = require('$base_dir/di').defaultModule; // (1)

require('$base_dir/core/EventBus');

require('path/to/dependency1d');
require('path/to/dependency2declaration');

// (2)
/**
 * @class
 *
 * A component that is happy to say hello to everyone
 *
 * @param {EventBus} eventBus
 * @param {Dependency1} dependency1
 * @param {Dependency2} dependency2
 */
function MyComponent(eventBus, dependency1, dependency2) {
  
  // (3.1)
  /**
   * Says hello to everyone.
   * 
   * @method MyComponent#sayHello
   *
   * @param {String} name the one to say hello to
   */
  function sayHello(name) {
    console.log('Hello, my name is', name);
  }

  // (3.2)
  /**
   * No docs yet :-(
   * @param {String} name
   */
  function asyncSayHello(name) {

    /**
     * An event indicating someone was just greeted
     *
     * @memberOf MyComponent
     *
     * @event my-custom-event
     *
     * @example
     *
     * // TODO: depict usage context if possible
     * 
     * @type {Object}
     * @property {String} name your name
     */
    eventBus.fire('mycomponent.sayHello', { name: name });
  }
  
  // (3.3)
  eventBus.on('diagram.init', function() {
    // perform initialization such as sending your own initializing events
    // YEE!
  });
  
  // (4)
  // API
  this.sayHello = sayHello;
  this.asyncSayHello = asyncSayHello;
}

// (4)
MyComponent.$inject([ 'dependency1Name', 'dependency2Name' ]);

defaultModule.type('myComponent', MyComponent);


// (5)
module.exports = MyComponent;
```

## Modularization


